@@ -3,6 +3,7 @@ from mvvmQt.rewriteContorls import Widget, Window, Label
 from PyQt5.QtWidgets import QWidget, QFrame, QPushButton, QGridLayout, QLayout, QHBoxLayout, QVBoxLayout, QLabel, QTabWidget\
     , QStatusBar, QButtonGroup, QAbstractButton, QRadioButton, QComboBox
 from mvvmQt.Observable import ObservableBase
+import asyncio
 
 class RowOrCol:
     def __init__(self, e):
@@ -101,12 +102,18 @@ class Element:
         else:
             ob.subscribe(lambda v: self.useQtFunc(c[0], self.changeValue(c[1], v), ob), init=True)
 
+    def callFunc(self, f, params):
+        if asyncio.iscoroutinefunction(f):
+            asyncio.get_event_loop().create_task(f(*params))
+        else:
+            f(*params)
+
     def addEvent(self, e):
         event = getattr(self.qt, e.key)
         if e.param:
-            event[str if e.param == 'str' else int].connect(lambda v: e.func(v, self))
+            event[str if e.param == 'str' else int].connect(lambda v: self.callFunc(e.func, [v, self]))
         else:
-            event.connect(lambda: e.func(self))
+            event.connect(lambda: self.callFunc(e.func, [self]))
 
     def bindAttr(self):
         for attr in self.attrs:
