@@ -28,8 +28,14 @@ class Parser:
         self.models = models
         self.events = events
 
+    def create_loop(self):
+        self.loop = QEventLoop(self.app)
+        asyncio.set_event_loop(self.loop)
+
     def build(self):
         self.app = QApplication(sys.argv)
+        self.create_loop()
+
         self.obj['desktop'] = QApplication.desktop()
         t = self.env.get_template("%s.jinja2" % self.indexName)
         html = t.render(**self.obj)
@@ -42,11 +48,8 @@ class Parser:
                 self.idElements[e.attrsToDict['id']] = e
 
     def run(self):
-        loop = QEventLoop(self.app)
-        asyncio.set_event_loop(loop)
-        # self.ui.run()
-        with loop:
-            loop.run_forever()
+        with self.loop:
+            self.loop.run_forever()
 
     def createElements(self, doc):
         list(map(self.loopChild, doc.children()))
