@@ -11,8 +11,9 @@ def groupChecked(*params):
     o: Element = params[-2]
     ob = params[-1]
 
-    if o.attrsToDict.get('twoWay', '1') == '1' and not getattr(o.qt, '_bindClicked', False):
-        #twoWay，双向绑定，0为否，1为是
+    attr = list(filter(lambda _: _.key == 'checked', o.attrs))[0]
+
+    if attr.twoWay and not getattr(o.qt, '_bindClicked', False):
         o.qt.buttonClicked[int].connect(lambda id: __updateObValue(ob, id, type(v)))
         o.qt._bindClicked = True
 
